@@ -2,12 +2,12 @@ test_that("generic_stroke() runs!", {
   iris$ord <-
     factor(sample(1:3, size = nrow(iris), replace = TRUE), ordered = TRUE)
   result <-
-    generic_stroke(
+    suppressMessages(generic_stroke(
       df = iris,
       group = "Species",
       score = "ord",
       variables = colnames(iris)[1:3]
-    )
+    ))
   expect_equal(length(result), 3)
   expect_equal(class(result), "list")
   expect_true("tbl_summary" %in% class(result[[1]]))
